@@ -97,7 +97,7 @@ exception_conversion_map = {
 class HyperVDriver(driver.ComputeDriver):
     capabilities = {
         "has_imagecache": True,
-        "supports_recreate": True,
+        "supports_evacuate": True,
         "supports_migrate_to_same_host": False,
         "supports_attach_interface": True,
         "supports_device_tagging": True,
@@ -105,6 +105,7 @@ class HyperVDriver(driver.ComputeDriver):
         "supports_tagged_attach_volume": True,
         "supports_extend_volume": True,
         "supports_multiattach": False,
+        "supports_trusted_certs": True,
     }
 
     def __init__(self, virtapi):
@@ -197,7 +198,7 @@ class HyperVDriver(driver.ComputeDriver):
                                       instance,
                                       update_device_metadata=True)
 
-    def detach_volume(self, connection_info, instance, mountpoint,
+    def detach_volume(self, context, connection_info, instance, mountpoint,
                       encryption=None):
         context = nova_context.get_admin_context()
         # The nova compute manager only updates the device metadata in
