@@ -34,10 +34,9 @@ from nova.tests.unit import conf_fixture
 from nova.tests.unit import policy_fixture
 from oslo_log.fixture import logging_error as log_fixture
 from oslo_log import log as logging
+from oslotest import base
 from oslotest import mock_fixture
-from oslotest import moxstubout
 import six
-import testtools
 
 import compute_hyperv.nova.conf
 
@@ -78,7 +77,7 @@ _patch_mock_to_raise_for_invalid_assert_calls()
 mock_fixture.patch_mock_module()
 
 
-class NoDBTestCase(testtools.TestCase):
+class NoDBTestCase(base.BaseTestCase):
     """Test case base class for all unit tests.
 
     Due to the slowness of DB access, please consider deriving from
@@ -107,9 +106,6 @@ class NoDBTestCase(testtools.TestCase):
         # because sqlalchemy-migrate messes with the warnings filters.
         self.useFixture(nova_fixtures.WarningsFixture())
 
-        mox_fixture = self.useFixture(moxstubout.MoxStubout())
-        self.mox = mox_fixture.mox
-        self.stubs = mox_fixture.stubs
         self.addCleanup(self._clear_attrs)
         self.policy = self.useFixture(policy_fixture.PolicyFixture())
 
