@@ -49,12 +49,6 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
         self.context = 'fake-context'
 
         self._migrationops = migrationops.MigrationOps()
-        self._migrationops._hostutils = mock.MagicMock()
-        self._migrationops._vmutils = mock.MagicMock()
-        self._migrationops._vhdutils = mock.MagicMock()
-        self._migrationops._migrationutils = mock.MagicMock()
-        self._migrationops._metricsutils = mock.MagicMock()
-        self._hostutils = self._migrationops._hostutils
         self._vmops = self._migrationops._vmops
         self._vmutils = self._migrationops._vmutils
         self._pathutils = self._migrationops._pathutils
@@ -531,7 +525,7 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
                 mock.call(root_device_path, mock_vhd_info,
                           mock_instance.flavor.root_gb * units.Gi))
         else:
-            self.assertFalse(self._pathutils.lookup_root_vhd.called)
+            self.assertFalse(self._pathutils.lookup_root_vhd_path.called)
 
         mock_check_resize_vhd.assert_has_calls(expected_check_resize)
         self._vhdutils.get_vhd_info.assert_has_calls(
