@@ -37,8 +37,6 @@ class SnapshotOpsTestCase(test_base.HyperVBaseTestCase):
 
         self.context = 'fake_context'
         self._snapshotops = snapshotops.SnapshotOps()
-        self._snapshotops._vmutils = mock.MagicMock()
-        self._snapshotops._vhdutils = mock.MagicMock()
 
     @mock.patch('nova.image.glance.get_remote_image_service')
     def test_save_glance_image(self, mock_get_remote_image_service):
@@ -57,7 +55,7 @@ class SnapshotOpsTestCase(test_base.HyperVBaseTestCase):
             mock.sentinel.PATH, 'rb')
         glance_image_service.update.assert_called_once_with(
             self.context, mock.sentinel.IMAGE_ID, image_metadata,
-            self._snapshotops._pathutils.open().__enter__(),
+            self._snapshotops._pathutils.open.return_value.__enter__(),
             purge_props=False)
 
     @mock.patch('compute_hyperv.nova.snapshotops.SnapshotOps'
